==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/helpers/csv_file_download_helper.rb <==
module CsvFileDownloadHelper
  include OrderHelper

  # ダウンロードパターン区分によって検索フォーム画面のレンダリングを制御します
  # CSVダウンロードボタンはパターン呼び出し後でないと押下できないため、
  # 初期表示時や、パターン呼び出し後の検索では押下できないように制御しています。
  def render_search_form(key, condition)
    result = ""
    partial_condition = nil
    partial_result = nil
    update_div_id = nil
    url = {}
    if [:user, :user_address].include?(key)
      partial_condition = '/user/search_condition'
      partial_result    = '/user/user_search_result'
      update_div_id     = "user_search_result"
      url               = {:controller => 'user', :action => 'index'}
      auth              = Goldberg.action_authorised?('user', 'index')
    elsif [:product, :product_sku, :product_display, :product_price, :product_component].include?(key)
      partial_condition = '/product/condition'
      partial_result    = '/product/search_result'
      update_div_id     = "product_search_result"
      url               = {:controller => 'product', :action => 'index'}
      auth              = Goldberg.action_authorised?('product', 'index')
    elsif [:order, :order_shipping, :order_item].include?(key)
      partial_condition = '/order/search_condition'
      partial_result    = '/order/order_search_result'
      update_div_id     = "order_search_result"
      url               = {:controller => 'order', :action => 'order_search'}
      auth              = Goldberg.action_authorised?('order', 'order_search')
    else
      return
    end

    # 権限が無い場合のHTML
    unless auth
      return "<p>ご指定のページにはアクセスする権限がありません。</p>"
    end

    result << render(:partial => partial_condition,
      :locals => {
        :form_method_and_args => [
          :remote_form_for, :condition, condition, {
            :update => update_div_id, :complete => "$('loading').style.display='none';$('csv_download_button').disabled = true;$('button_description').style.display='';",
            :url => url
          }
        ]
      })
    if @csv_download_pattern.id
      result << button_to("CSVダウンロード", {:action => :download, :id => @csv_download_pattern.id}, {:id => "csv_download_button"})
      result << "<p id=\"button_description\" style=\"display: none;\">※パターンを登録をするか、パターン呼び出しをしてください。<p>"
    else
      result << button_to("CSVダウンロード", {:action => :download, :id => @csv_download_pattern.id}, {:disabled => true, :id => "csv_download_button"})
      result << "<p id=\"button_description\">※パターンを登録をするか、パターン呼び出しをしてください。<p>"
    end
    result << "<div id=\"#{update_div_id}\">"
    result << render(:partial => partial_result, :locals => {:invoked => 'csv'})
    result << "</div>"

    return result
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/helpers/csv_file_download_helper.rb <==
module CsvFileDownloadHelper
  include OrderHelper

  # ダウンロードパターン区分によって検索フォーム画面のレンダリングを制御します
  # CSVダウンロードボタンはパターン呼び出し後でないと押下できないため、
  # 初期表示時や、パターン呼び出し後の検索では押下できないように制御しています。
  def render_search_form(key, condition)
    result = ""
    partial_condition = nil
    partial_result = nil
    update_div_id = nil
    url = {}
    if [:user, :user_address].include?(key)
      partial_condition = '/user/search_condition'
      partial_result    = '/user/user_search_result'
      update_div_id     = "user_search_result"
      url               = {:controller => 'user', :action => 'index'}
      auth              = Goldberg.action_authorised?('user', 'index')
    elsif [:product, :product_sku, :product_display, :product_price, :product_component].include?(key)
      partial_condition = '/product/condition'
      partial_result    = '/product/search_result'
      update_div_id     = "product_search_result"
      url               = {:controller => 'product', :action => 'index'}
      auth              = Goldberg.action_authorised?('product', 'index')
    elsif [:order, :order_shipping, :order_item, :order_item_component].include?(key)
      partial_condition = '/order/search_condition'
      partial_result    = '/order/order_search_result'
      update_div_id     = "order_search_result"
      url               = {:controller => 'order', :action => 'order_search'}
      auth              = Goldberg.action_authorised?('order', 'order_search')
    elsif [:accounting].include?(key)
      partial_condition = '/accountings/search_condition'
      partial_result    = '/accountings/search_result'
      update_div_id     = "accounting_search_result"
      url               = {:controller => 'accountings', :action => 'index'}
      auth              = Goldberg.action_authorised?('accountings', 'index')
    else
      return
    end

    # 権限が無い場合のHTML
    unless auth
      return "<p>ご指定のページにはアクセスする権限がありません。</p>"
    end

    result << render(:partial => partial_condition,
      :locals => {
        :form_method_and_args => [
          :remote_form_for, :condition, condition, {
            :update => update_div_id, :complete => "$('loading').style.display='none';$('csv_download_button').disabled = true;$('button_description').style.display='';",
            :url => url
          }
        ]
      })
    if @csv_download_pattern.id
      result << button_to("CSVダウンロード", {:action => :download, :id => @csv_download_pattern.id}, {:id => "csv_download_button"})
      result << "<p id=\"button_description\" style=\"display: none;\">※パターンを登録をするか、パターン呼び出しをしてください。<p>"
    else
      result << button_to("CSVダウンロード", {:action => :download, :id => @csv_download_pattern.id}, {:disabled => true, :id => "csv_download_button"})
      result << "<p id=\"button_description\">※パターンを登録をするか、パターン呼び出しをしてください。<p>"
    end
    result << "<div id=\"#{update_div_id}\">"
    result << render(:partial => partial_result, :locals => {:invoked => 'csv'})
    result << "</div>"

    return result
  end
end
